@@ -1,17 +1,44 @@
 package Osgood::Event;
 use Moose;
+use MooseX::Storage;
+use MooseX::AttributeHelpers;
 
 use DateTime;
+use DateTime::Format::ISO8601;
+
+with Storage('format' => 'JSON', 'io' => 'File');
 
 has 'id' => ( is => 'rw', isa => 'Int'  );
 has 'action' => ( is => 'rw', isa => 'Str', required => 1 );
 has 'date_occurred' => (
-	is => 'rw',
-	isa => 'DateTime',
-	default => sub { DateTime->now() }
+    is => 'rw',
+    isa => 'DateTime',
+    default => sub { DateTime->now }
 );
 has 'object' => ( is => 'rw', isa => 'Str', required => 1 );
-has 'params' => ( is => 'rw', isa => 'HashRef', default => sub{ {} } );
+has 'params' => (
+    metaclass => 'Collection::Hash',
+    is => 'rw',
+    isa => 'HashRef',
+    default => sub{ {} },
+    provides => {
+        get => 'get_param',
+        set => 'set_param'
+    }
+);
+
+MooseX::Storage::Engine->add_custom_type_handler(
+    'DateTime' => (
+        expand => sub { DateTime::Format::ISO8601->parse_datetime(shift) },
+        collapse => sub { (shift)->iso8601 }
+    )
+);
+
+__PACKAGE__->meta->make_immutable;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -28,68 +55,39 @@ Note: object and action names are limited to 64 characters.
 
 =head1 SYNOPSIS
 
-  my $event = new Osgood::Event(object => 'Test', action => 'create');
+  my $event = Osgood::Event->new(object => 'Test', action => 'create');
 
 =head1 METHODS
 
-=head2 Constructor
-
-=over 4
-
-=item new
+=head2 new
 
 Creates a new Osgood::Event object.  Requires an object and action.  If no
-date_occurred is specifed, then the DateTime->now() is used.
+date_occurred is specifed, then the C<DateTime->now> is used.
 
-=back
-
-=head2 Class Methods
-
-=over 4
-
-=item action
+=head2 action
 
 The action this event represents.
 
-=item date_occurred
+=head2 date_occurred
 
 The date and time this event occurred
 
-=item object
+=head2 object
 
 The object this event pertains to.
 
-=item params
+=head2 params
 
 A HashRef of name-value pairs for this event.
 
-=item set_param
+=head2 set_param
 
 Allows setting a single name value pair directly.
 
-=cut
-sub set_param {
-	my $self	= shift();
-	my $key		= shift() or die('Must supply a key and value to set_param.');
-	my $value	= shift();
-
-	$self->params->{$key} = $value;
-}
-
-=item get_param
+=head2 get_param
 
 Get the value of the specifed key.
 
-=cut
-sub get_param {
-	my $self	= shift();
-	my $key 	= shift() or die('Must supply a key to get_param.');
-
-	return $self->params->{$key};
-}
-
-=back
-
 =head1 AUTHOR
 
 Cory 'G' Watson <gphat@cpan.org>
@@ -100,11 +98,7 @@ perl(1), Osgood::EventList
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 by Magazines.com, LLC
+Copyright 2008-2009 by Magazines.com, LLC
 
 You can redistribute and/or modify this code under the same terms as Perl
 itself.
-
-=cut
-
-1;
\ No newline at end of file
